%define dkms_name openrazer-driver

Name:     openrazer-meta
Version:  3.8.0
Release:  %mkrel 4
Summary:  Driver and user-space daemon for managing Razer devices
Group:    System/Configuration
URL:      https://github.com/openrazer/openrazer
License:  GPL-2.0
Source0:  https://github.com/openrazer/openrazer/releases/download/v%{version}/openrazer-%{version}.tar.xz

BuildArch: noarch

Requires: openrazer-kernel-modules-dkms
Requires: openrazer-daemon
Requires: python3-openrazer

Obsoletes:  razercfg

%description
Meta package for installing all required openrazer packages.


%package -n openrazer-kernel-modules-dkms
Summary:  OpenRazer Driver DKMS package
Group:    System/Kernel and hardware

Provides: razer-kernel-modules-dkms

Requires: dkms
Requires: make
Requires: udev

Requires(pre): shadow-utils

%description -n openrazer-kernel-modules-dkms
Kernel driver for Razer devices (DKMS-variant)


%package -n openrazer-daemon
Summary:  OpenRazer Service package
Group:    System/Libraries

BuildRequires: python3-devel
BuildRequires: python3-setuptools

Provides: razer-daemon

Requires: openrazer-kernel-modules-dkms
Requires: python3
Requires: python3-dbus
Requires: python3-gobject3
Requires: python3-setproctitle
Requires: python3-pyudev
Requires: python3-daemonize
Requires: xautomation

%description -n openrazer-daemon
Userspace daemon that abstracts access to the kernel driver. Provides a DBus service for applications to use.


%package -n python3-openrazer
Summary:  OpenRazer Python library
Group:    Development/Python

BuildRequires: python3-devel
BuildRequires: python3-setuptools

Provides: python3-razer

Requires: openrazer-daemon
Requires: python3
Requires: python3-dbus
Requires: python3-gobject3
Requires: python3-numpy

%description -n python3-openrazer
Python library for accessing the daemon from Python.


%prep
%autosetup -p1 -n openrazer-%{version}

cat > README.%_real_vendor <<EOF
============================================
Users have to be added to plugdev group:

  su -c "gpasswd -a <Your_Username> plugdev"

and razerd service enabled:

  systemctl --user enable --now openrazer-daemon

Then, logoff/login or reboot.
============================================
EOF

%build
# noop

%install
# setup_dkms & udev_install -> razer-kernel-modules-dkms
# daemon_install -> razer_daemon
# python_library_install -> python3-razer
make DESTDIR=%{buildroot} setup_dkms udev_install daemon_install python_library_install

install -m644 README.%_real_vendor README.urpmi


%pre -n openrazer-kernel-modules-dkms
#!/bin/sh
set -e
getent group plugdev >/dev/null || groupadd -r plugdev

%posttrans -n openrazer-kernel-modules-dkms
dkms add -m %{dkms_name} -v %{version} --rpm_safe_upgrade
dkms build -m %{dkms_name} -v %{version} --rpm_safe_upgrade
dkms install -m %{dkms_name} -v %{version} --rpm_safe_upgrade

%preun -n openrazer-kernel-modules-dkms
dkms remove -m %{dkms_name} -v %{version} --rpm_safe_upgrade --all


%files
%doc README.urpmi

%files -n openrazer-kernel-modules-dkms
%defattr(-,root,root,-)
# A bit hacky but it works
%{_udevrulesdir}/../razer_mount
%{_udevrulesdir}/99-razer.rules
%{_usrsrc}/%{dkms_name}-%{version}/

%files -n openrazer-daemon
%{_bindir}/openrazer-daemon
%{python3_sitelib}/openrazer_daemon/
%{python3_sitelib}/openrazer_daemon-*.egg-info/
%{_datadir}/openrazer/
%{_datadir}/dbus-1/services/org.razer.service
%{_prefix}/lib/systemd/user/openrazer-daemon.service
%{_mandir}/man5/razer.conf.5*
%{_mandir}/man8/openrazer-daemon.8*

%files -n python3-openrazer
%{python3_sitelib}/openrazer/
%{python3_sitelib}/openrazer-*.egg-info/


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 3.8.0-4.mga10
+ Revision: 2242857
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 3.8.0-3.mga10
+ Revision: 2160411
- rebuild for python3.13

* Sat May 18 2024 squidf <squidf> 3.8.0-2.mga10
+ Revision: 2064756
-First MGA package inspired by openSUSE


* Sun Apr 28 2024 squidf <squid-f> 3.8.0-1
- Update to 3.8.0

* Sat Dec 2 2023 squidf <squid-f> 3.7.0-0
- Initial Mageia package, based on OBS
